@@ -16,10 +16,10 @@ cp gallery1-to-slideshow /usr/bin/.
 cp jigl2slideshow /usr/bin/.
 cp dir2slideshow /usr/bin/.
 
-remove old versions:
-if [ -r "/usr/bin/gallery2slideshow" ] ; then
-	echo "Removing old gallery2slideshow and installing gallery1-to-slideshow instead"
-	echo "See changelog for details."
+# remove old versions:
+if [ -r '/usr/bin/gallery2slideshow' ] ; then
+	echo 'Removing old gallery2slideshow and installing gallery1-to-slideshow instead'
+	echo 'See changelog for details.'
 	rm "/usr/bin/gallery2slideshow"
 	rm "/usr/local/man/man1/gallery2slideshow.1"
 fi
